@@ -32,11 +32,11 @@ class AdsApi:
                         if data[i] == None:
                             del data[i]
                 response = methods[method](
-                    self.base_url_ads + endpoint, params=params, data=data, json=json, timeout =2).json()
+                    self.base_url_ads + endpoint, params=params, data=data, json=json, timeout =5).json()
                 self.lock.release()
             except:
                 self.lock.release()
-                log.error(f'Error with {req_info}-- {traceback.format_exc()}')
+                #log.error(f'Error with {req_info}-- {traceback.format_exc()}')
                 if attempt == attempts-1:
                     raise AdsError('')
                 continue
